@@ -41,6 +41,7 @@ __license__ = "MIT"
 
 _logger = logging.getLogger(__name__)
 
+
 try:
     from . import menu
 except NotImplementedError:
@@ -221,9 +222,8 @@ def main(args):
         googlesheets.main(out)
 
     windows = platform.system() == "Windows" or platform.system().startswith("CYGWIN")
-    if args.show_reports:
-        if not windows:
-            menu.main()
+    if args.show_reports and not windows:
+        menu.main()
 
 
 def run():
